/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 04099
 |         NATIONAL SURVEY OF SUBSTANCE ABUSE TREATMENT SERVICES
 |                            (N-SSATS), 2003
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 04099-0001-statasetup.do)
 |
 **************************************************************************/

set mem 20m  /* Allocating 20 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "National Survey of Substance Abuse Treatment Services (N-SSATS), 2003"

#delimit ;
label define MODE      1 "Phone" 2 "Mail" 9 "Web" ;
label define STFIPS    1 "ALABAMA" 2 "ALASKA" 4 "ARIZONA" 5 "ARKANSAS"
                       6 "CALIFORNIA" 8 "COLORADO" 9 "CONNECTICUT"
                       10 "DELAWARE" 11 "DIST OF COLUMBIA" 12 "FLORIDA"
                       13 "GEORGIA" 15 "HAWAII" 16 "IDAHO" 17 "ILLINOIS"
                       18 "INDIANA" 19 "IOWA" 20 "KANSAS" 21 "KENTUCKY"
                       22 "LOUISIANA" 23 "MAINE" 24 "MARYLAND"
                       25 "MASSACHUSETTS" 26 "MICHIGAN" 27 "MINNESOTA"
                       28 "MISSISSIPPI" 29 "MISSOURI" 30 "MONTANA"
                       31 "NEBRASKA" 32 "NEVADA" 33 "NEW HAMPSHIRE"
                       34 "NEW JERSEY" 35 "NEW MEXICO" 36 "NEW YORK"
                       37 "NORTH CAROLINA" 38 "NORTH DAKOTA" 39 "OHIO"
                       40 "OKLAHOMA" 41 "OREGON" 42 "PENNSYLVANIA"
                       44 "RHODE ISLAND" 45 "SOUTH CAROLINA"
                       46 "SOUTH DAKOTA" 47 "TENNESSEE" 48 "TEXAS" 49 "UTAH"
                       50 "VERMONT" 51 "VIRGINIA" 53 "WASHINGTON"
                       54 "WEST VIRGINIA" 55 "WISCONSIN" 56 "WYOMING"
                       60 "AMERICAN SAMOA" 64 "FED MICRONESIA" 66 "GUAM"
                       70 "PALAU" 72 "PUERTO RICO" 78 "VIRGIN ISLANDS" ;
label define REGION    0 "US Jurisdiction/Territory" 1 "Northeast"
                       2 "Midwest" 3 "South" 4 "West" ;
label define DIVISION  0 "US Jurisdiction/Territory" 1 "New England"
                       2 "Mid-Atlantic" 3 "East North Central"
                       4 "West North Central" 5 "South Atlantic"
                       6 "East South Central" 7 "West South Central"
                       8 "Mountain" 9 "Pacific" ;
label define OTHNONTX  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define DETOX     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define TREATMT   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LOC5      -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define ADMIN     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define FOCUS     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 1 "Substance abuse treatment services"
                       2 "Mental health services"
                       3 "Mix of mental health and substance abuse"
                       4 "General health care" 5 "Other" ;
label define OWNERSHP  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 1 "Private for-profit organization"
                       2 "Private non-profit organization"
                       3 "State government"
                       4 "Local, county, or community government"
                       5 "Tribal government" 6 "Federal government" ;
label define FEDOWN    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 1 "Department of Veterans Affairs"
                       2 "Department of Defense" 3 "Indian Health Service"
                       4 "Other" ;
label define LOC15     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define RELIG     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define HOSPITAL  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LOCS      -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 1 "General hospital (including VA)"
                       2 "Psychiatric hospital" 3 "Other specialty hospital" ;
label define HOTYN     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC1     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC2     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC4     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC5     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC6     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC8     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC27    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC70    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC71    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC72    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC10    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC11    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC73    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC74    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC14    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC15    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC16    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC36    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC37    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC38    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC39    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC49    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC50    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC52    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC24    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC55    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC59    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC48    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC75    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define OTP       -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define OTPTYPE   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 1 "Maintenance program"
                       2 "Detoxification program" 3 "Both" ;
label define OTPALL    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define DUI_DWI   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define ONLYDUI   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SIGNLANG  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG      -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG1     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG2     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG3     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG4     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG5     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG6     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG7     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG8     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG9     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG10    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG11    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG12    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG13    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG14    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG15    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG16    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG17    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LANG18    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes"
                       2 "Yes, via interpreter"
                       3 "Yes, via telephone service" ;
label define SRVC76    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC30    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC77    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC31    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC78    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC61    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC79    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC32    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC80    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC62    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC81    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC63    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC82    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC33    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC83    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC34    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC84    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC64    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SRVC35    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define CTYPE4    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define CTYPEHI1  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define CTYPEHI2  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define CTYPE7    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define CTYPERC1  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define CTYPERC3  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define CTYPERC4  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define CTYPE1    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define CTYPE6    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define CTYPEML   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define CTYPEOP   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define CTYPE2    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define CTYPE3    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define FEESCALE  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define PAYASST   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define REVCHK1   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define REVCHK8   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define REVCHK5   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define REVCHK10  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define REVCHK15  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define REVCHK2   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define REVCHK3   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define REVCHK2A  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define EARMARK   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define WRITARRA  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define SAT       -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define OTHFAC2   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define OTHFAC1   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define OTHFAC3   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define TYPE4     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define T_CLI1    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define T_CLI2    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define T_CLIHI   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define H_AGE1    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define HIMETNUM  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define HILAMNUM  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define HOSPBED   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define TYPE7     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define T_CLI3    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define T_CLI9    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define T_CLI10   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define T_CLIRC   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define R_AGE1    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define RCMETNUM  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define RCLAMNUM  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define RESBED    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define TYPE1     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define T_CLI7    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define T_CLIML   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define T_CLI8    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define T_CLI6    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define T_CLI5    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define T_CLIOP   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define O_AGE1    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define OPMETNUM  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define OPLAMNUM  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define B_PCT     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define A_PCT     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define D_PCT     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define TOTADMIS  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define FACCLI    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 1 "Only this facility"
                       2 "This facility plus others" ;
label define FACNUM    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define ACTHI     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 1 "Actual" 2 "Estimate" ;
label define ACTRES    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 1 "Actual" 2 "Estimate" ;
label define ACTOP     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 1 "Actual" 2 "Estimate" ;
label define TOTADEST  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 1 "Actual" 2 "Estimate" ;
label define LICENSED  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LICENMH   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LICENPH   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define LICENHOS  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define JCAHO     -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define CARF      -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define NCQA      -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define COA       -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define OTHSTATE  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define INTERNET  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define HASWEB    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 0 "No" 1 "Yes" ;
label define RPTLVL    -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" 1 "Reporting for self"
                       2 "Reporting for self and others"
                       3 "Client counts reported by another facility" ;
label define T_CLI11   -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define T_CLIJUV  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define T_CLIMET  -10 "Elsewhere" -9 "Not in survey" -8 "Not in mode"
                       -7 "Not Applicable" -6 "Logical Skip"
                       -5 "Multiple Responses" -4 "Refused" -2 "Missing"
                       -1 "Don't Know" ;
label define OWNRSPFL  0 "Data Not Imputed" 1 "Data Imputed" ;
label define OTPFL     0 "Data Not Imputed" 1 "Data Imputed" ;
label define OTPTYPEF  0 "Data Not Imputed" 1 "Data Imputed" ;
label define OTPALLFL  0 "Data Not Imputed" 1 "Data Imputed" ;
label define LANGFL    0 "Data Not Imputed" 1 "Data Imputed" ;
label define OTHFAC2F  0 "Data Not Imputed" 1 "Data Imputed" ;
label define OTHFAC1F  0 "Data Not Imputed" 1 "Data Imputed" ;
label define TYPE4FL   0 "Data Not Imputed" 1 "Data Imputed" ;
label define T_CLIHIF  0 "Data Not Imputed" 1 "Data Imputed" ;
label define HIMTLAMF  0 "Data Not Imputed" 1 "Data Imputed" ;
label define HOSPBEDF  0 "Data Not Imputed" 1 "Data Imputed" ;
label define TYPE7FL   0 "Data Not Imputed" 1 "Data Imputed" ;
label define T_CLIRCF  0 "Data Not Imputed" 1 "Data Imputed" ;
label define RCMTLAMF  0 "Data Not Imputed" 1 "Data Imputed" ;
label define RESBEDFL  0 "Data Not Imputed" 1 "Data Imputed" ;
label define TYPE1FL   0 "Data Not Imputed" 1 "Data Imputed" ;
label define T_CLIOPF  0 "Data Not Imputed" 1 "Data Imputed" ;
label define OPMTLAMF  0 "Data Not Imputed" 1 "Data Imputed" ;
label define PCTFL     0 "Data Not Imputed" 1 "Data Imputed" ;
label define TOTADMFL  0 "Data Not Imputed" 1 "Data Imputed" ;
label define FACNUMFL  0 "Data Not Imputed" 1 "Data Imputed" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace OTHNONTX = . if (OTHNONTX <= -1 )
replace DETOX = . if (DETOX <= -1 )
replace TREATMT = . if (TREATMT <= -1 )
replace LOC5 = . if (LOC5 <= -1 )
replace ADMIN = . if (ADMIN <= -1 )
replace FOCUS = . if (FOCUS <= -1 )
replace OWNERSHP = . if (OWNERSHP <= -1 )
replace FEDOWN = . if (FEDOWN <= -1 )
replace LOC15 = . if (LOC15 <= -1 )
replace RELIG = . if (RELIG <= -1 )
replace HOSPITAL = . if (HOSPITAL <= -1 )
replace LOCS = . if (LOCS <= -1 )
replace HOTYN = . if (HOTYN <= -1 )
replace SRVC1 = . if (SRVC1 <= -1 )
replace SRVC2 = . if (SRVC2 <= -1 )
replace SRVC4 = . if (SRVC4 <= -1 )
replace SRVC5 = . if (SRVC5 <= -1 )
replace SRVC6 = . if (SRVC6 <= -1 )
replace SRVC8 = . if (SRVC8 <= -1 )
replace SRVC27 = . if (SRVC27 <= -1 )
replace SRVC70 = . if (SRVC70 <= -1 )
replace SRVC71 = . if (SRVC71 <= -1 )
replace SRVC72 = . if (SRVC72 <= -1 )
replace SRVC10 = . if (SRVC10 <= -1 )
replace SRVC11 = . if (SRVC11 <= -1 )
replace SRVC73 = . if (SRVC73 <= -1 )
replace SRVC74 = . if (SRVC74 <= -1 )
replace SRVC14 = . if (SRVC14 <= -1 )
replace SRVC15 = . if (SRVC15 <= -1 )
replace SRVC16 = . if (SRVC16 <= -1 )
replace SRVC36 = . if (SRVC36 <= -1 )
replace SRVC37 = . if (SRVC37 <= -1 )
replace SRVC38 = . if (SRVC38 <= -1 )
replace SRVC39 = . if (SRVC39 <= -1 )
replace SRVC49 = . if (SRVC49 <= -1 )
replace SRVC50 = . if (SRVC50 <= -1 )
replace SRVC52 = . if (SRVC52 <= -1 )
replace SRVC24 = . if (SRVC24 <= -1 )
replace SRVC55 = . if (SRVC55 <= -1 )
replace SRVC59 = . if (SRVC59 <= -1 )
replace SRVC48 = . if (SRVC48 <= -1 )
replace SRVC75 = . if (SRVC75 <= -1 )
replace OTP = . if (OTP <= -1 )
replace OTPTYPE = . if (OTPTYPE <= -1 )
replace OTPALL = . if (OTPALL <= -1 )
replace DUI_DWI = . if (DUI_DWI <= -1 )
replace ONLYDUI = . if (ONLYDUI <= -1 )
replace SIGNLANG = . if (SIGNLANG <= -1 )
replace LANG = . if (LANG <= -1 )
replace LANG1 = . if (LANG1 <= -1 )
replace LANG2 = . if (LANG2 <= -1 )
replace LANG3 = . if (LANG3 <= -1 )
replace LANG4 = . if (LANG4 <= -1 )
replace LANG5 = . if (LANG5 <= -1 )
replace LANG6 = . if (LANG6 <= -1 )
replace LANG7 = . if (LANG7 <= -1 )
replace LANG8 = . if (LANG8 <= -1 )
replace LANG9 = . if (LANG9 <= -1 )
replace LANG10 = . if (LANG10 <= -1 )
replace LANG11 = . if (LANG11 <= -1 )
replace LANG12 = . if (LANG12 <= -1 )
replace LANG13 = . if (LANG13 <= -1 )
replace LANG14 = . if (LANG14 <= -1 )
replace LANG15 = . if (LANG15 <= -1 )
replace LANG16 = . if (LANG16 <= -1 )
replace LANG17 = . if (LANG17 <= -1 )
replace LANG18 = . if (LANG18 <= -1 )
replace SRVC76 = . if (SRVC76 <= -1 )
replace SRVC30 = . if (SRVC30 <= -1 )
replace SRVC77 = . if (SRVC77 <= -1 )
replace SRVC31 = . if (SRVC31 <= -1 )
replace SRVC78 = . if (SRVC78 <= -1 )
replace SRVC61 = . if (SRVC61 <= -1 )
replace SRVC79 = . if (SRVC79 <= -1 )
replace SRVC32 = . if (SRVC32 <= -1 )
replace SRVC80 = . if (SRVC80 <= -1 )
replace SRVC62 = . if (SRVC62 <= -1 )
replace SRVC81 = . if (SRVC81 <= -1 )
replace SRVC63 = . if (SRVC63 <= -1 )
replace SRVC82 = . if (SRVC82 <= -1 )
replace SRVC33 = . if (SRVC33 <= -1 )
replace SRVC83 = . if (SRVC83 <= -1 )
replace SRVC34 = . if (SRVC34 <= -1 )
replace SRVC84 = . if (SRVC84 <= -1 )
replace SRVC64 = . if (SRVC64 <= -1 )
replace SRVC35 = . if (SRVC35 <= -1 )
replace CTYPE4 = . if (CTYPE4 <= -1 )
replace CTYPEHI1 = . if (CTYPEHI1 <= -1 )
replace CTYPEHI2 = . if (CTYPEHI2 <= -1 )
replace CTYPE7 = . if (CTYPE7 <= -1 )
replace CTYPERC1 = . if (CTYPERC1 <= -1 )
replace CTYPERC3 = . if (CTYPERC3 <= -1 )
replace CTYPERC4 = . if (CTYPERC4 <= -1 )
replace CTYPE1 = . if (CTYPE1 <= -1 )
replace CTYPE6 = . if (CTYPE6 <= -1 )
replace CTYPEML = . if (CTYPEML <= -1 )
replace CTYPEOP = . if (CTYPEOP <= -1 )
replace CTYPE2 = . if (CTYPE2 <= -1 )
replace CTYPE3 = . if (CTYPE3 <= -1 )
replace FEESCALE = . if (FEESCALE <= -1 )
replace PAYASST = . if (PAYASST <= -1 )
replace REVCHK1 = . if (REVCHK1 <= -1 )
replace REVCHK8 = . if (REVCHK8 <= -1 )
replace REVCHK5 = . if (REVCHK5 <= -1 )
replace REVCHK10 = . if (REVCHK10 <= -1 )
replace REVCHK15 = . if (REVCHK15 <= -1 )
replace REVCHK2 = . if (REVCHK2 <= -1 )
replace REVCHK3 = . if (REVCHK3 <= -1 )
replace REVCHK2A = . if (REVCHK2A <= -1 )
replace EARMARK = . if (EARMARK <= -1 )
replace WRITARRA = . if (WRITARRA <= -1 )
replace SAT = . if (SAT <= -1 )
replace OTHFAC2 = . if (OTHFAC2 <= -1 )
replace OTHFAC1 = . if (OTHFAC1 <= -1 )
replace OTHFAC3 = . if (OTHFAC3 <= -1 )
replace TYPE4 = . if (TYPE4 <= -1 )
replace T_CLI1 = . if (T_CLI1 <= -1 )
replace T_CLI2 = . if (T_CLI2 <= -1 )
replace T_CLIHI = . if (T_CLIHI <= -1 )
replace H_AGE1 = . if (H_AGE1 <= -1 )
replace HIMETNUM = . if (HIMETNUM <= -1 )
replace HILAMNUM = . if (HILAMNUM <= -1 )
replace HOSPBED = . if (HOSPBED <= -1 )
replace TYPE7 = . if (TYPE7 <= -1 )
replace T_CLI3 = . if (T_CLI3 <= -1 )
replace T_CLI9 = . if (T_CLI9 <= -1 )
replace T_CLI10 = . if (T_CLI10 <= -1 )
replace T_CLIRC = . if (T_CLIRC <= -1 )
replace R_AGE1 = . if (R_AGE1 <= -1 )
replace RCMETNUM = . if (RCMETNUM <= -1 )
replace RCLAMNUM = . if (RCLAMNUM <= -1 )
replace RESBED = . if (RESBED <= -1 )
replace TYPE1 = . if (TYPE1 <= -1 )
replace T_CLI7 = . if (T_CLI7 <= -1 )
replace T_CLIML = . if (T_CLIML <= -1 )
replace T_CLI8 = . if (T_CLI8 <= -1 )
replace T_CLI6 = . if (T_CLI6 <= -1 )
replace T_CLI5 = . if (T_CLI5 <= -1 )
replace T_CLIOP = . if (T_CLIOP <= -1 )
replace O_AGE1 = . if (O_AGE1 <= -1 )
replace OPMETNUM = . if (OPMETNUM <= -1 )
replace OPLAMNUM = . if (OPLAMNUM <= -1 )
replace B_PCT = . if (B_PCT <= -1 )
replace A_PCT = . if (A_PCT <= -1 )
replace D_PCT = . if (D_PCT <= -1 )
replace TOTADMIS = . if (TOTADMIS <= -1 )
replace FACCLI = . if (FACCLI <= -1 )
replace FACNUM = . if (FACNUM <= -1 )
replace ACTHI = . if (ACTHI <= -1 )
replace ACTRES = . if (ACTRES <= -1 )
replace ACTOP = . if (ACTOP <= -1 )
replace TOTADEST = . if (TOTADEST <= -1 )
replace LICENSED = . if (LICENSED <= -1 )
replace LICENMH = . if (LICENMH <= -1 )
replace LICENPH = . if (LICENPH <= -1 )
replace LICENHOS = . if (LICENHOS <= -1 )
replace JCAHO = . if (JCAHO <= -1 )
replace CARF = . if (CARF <= -1 )
replace NCQA = . if (NCQA <= -1 )
replace COA = . if (COA <= -1 )
replace OTHSTATE = . if (OTHSTATE <= -1 )
replace INTERNET = . if (INTERNET <= -1 )
replace HASWEB = . if (HASWEB <= -1 )
replace RPTLVL = . if (RPTLVL <= -1 )
replace T_CLI11 = . if (T_CLI11 <= -1 )
replace T_CLIJUV = . if (T_CLIJUV <= -1 )
replace T_CLIMET = . if (T_CLIMET <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

